@@ -21,5 +21,5 @@ test_that("fails correctly", {
   skip_on_cran()
   
   expect_error(enumeration("asdfadsf"), "Status: 204 - not found")
-  expect_error(enumeration_country("asdfadsf"), "is not TRUE")
+  expect_error(enumeration_country("asdfadsf"), "no applicable method for 'as.request'")
 })
