@@ -1,15 +1,17 @@
 context("occ_get")
 
-tt <- occ_get(key=766766824, return='data')
-uu <- occ_get(key=766766824, 'hier')
-vv <- occ_get(key=766766824, 'all')
-
-aa <- occ_get(key=766766824, verbatim = TRUE)
-bb <- occ_get(key=766766824, verbatim = TRUE, fields = "all")
-cc <- occ_get(key=c(766766824,620594291,766420684), 
-        fields=c('scientificName','decimalLatitude','basisOfRecord'), verbatim=TRUE)
-
 test_that("returns the correct class", {
+  skip_on_cran()
+  
+  tt <- occ_get(key=766766824, return='data')
+  uu <- occ_get(key=766766824, 'hier')
+  vv <- occ_get(key=766766824, 'all')
+  
+  aa <- occ_get(key=766766824, verbatim = TRUE)
+  bb <- occ_get(key=766766824, verbatim = TRUE, fields = "all")
+  cc <- occ_get(key=c(766766824,620594291,766420684), 
+                fields=c('scientificName','decimalLatitude','basisOfRecord'), verbatim=TRUE)
+  
   expect_is(tt, "data.frame")
   expect_is(tt[1,1], "character")
   expect_is(tt[1,2], "integer")
@@ -29,9 +31,8 @@ test_that("returns the correct class", {
   expect_is(bb, "data.frame")
   expect_is(bb[1,10], "character")
   expect_is(bb[1,2], "character")
-})
 
-test_that("returns the correct dimensions", {
+  # returns the correct dimensions
   expect_equal(dim(tt), c(1,5))
   expect_equal(dim(uu), c(7,3))
   expect_equal(dim(vv), NULL)
@@ -43,5 +44,6 @@ test_that("returns the correct dimensions", {
 })
 
 test_that("name_usage fails correctly", {
+  skip_on_cran()
   expect_error(occ_get(key=766766824, config=timeout(0.001)))
 })
